@@ -6,7 +6,7 @@ mod closure;
 mod constants;
 pub mod cps;
 pub mod extra;
-mod future;
+pub mod future;
 mod none;
 mod number;
 mod string;
@@ -17,7 +17,6 @@ pub use boolean::*;
 pub use box_any::*;
 pub use closure::*;
 pub use constants::*;
-pub use future::*;
 pub use none::*;
 pub use number::*;
 pub use pen_ffi_macro::*;
